All stuff is available worldwild 

It's a personal project, publishing python automatisations for Data Analysts...


from wild import eda :
An automation module for obtaining an overview of a dataset: empty cells(nan), mean, quartiles, dtype, etc... a css code color the columns of nan values...
A second Dataset is an overview of the rows that contain empty cells.